pycalphad.mapping package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pycalphad.mapping.strategy

Submodules
----------

pycalphad.mapping.compat\_api module
------------------------------------

.. automodule:: pycalphad.mapping.compat_api
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.plotting module
---------------------------------

.. automodule:: pycalphad.mapping.plotting
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.primitives module
-----------------------------------

.. automodule:: pycalphad.mapping.primitives
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.starting\_points module
-----------------------------------------

.. automodule:: pycalphad.mapping.starting_points
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.utils module
------------------------------

.. automodule:: pycalphad.mapping.utils
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.zpf\_checks module
------------------------------------

.. automodule:: pycalphad.mapping.zpf_checks
   :members:
   :undoc-members:
   :show-inheritance:

pycalphad.mapping.zpf\_equilibrium module
-----------------------------------------

.. automodule:: pycalphad.mapping.zpf_equilibrium
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pycalphad.mapping
   :members:
   :undoc-members:
   :show-inheritance:
